@@ -50,7 +50,6 @@
 #'
 #' @references Patterson, H.D., and E.R. Williams. 1976. A new class of
 #' resolvable incomplete block designs. Biometrika 63:83-92.
-#' \href{https://doi.org/10.1093/biomet/63.1.83}{doi:10.1093/biomet/63.1.83}
 #'
 #' @return An object of class \code{cv_ammi} with the following items: *
 #' \strong{RMSPD}: A vector with nboot-estimates of the Root Mean Squared
@@ -93,7 +92,7 @@ cv_ammi <- function(.data, env, gen, rep, resp, block = NULL, naxis = 2, nboot =
                     GEN = {{gen}},
                     REP = {{rep}},
                     Y = {{resp}})%>%
-      mutate_at(1:3, as.factor)
+      mutate(across(1:3, as.factor))
     RMSPDres <- data.frame(RMSPD = matrix(0, nboot, 1))
     data <- tibble::rowid_to_column(data)
     Nenv <- length(unique(data$ENV))
