@@ -34,7 +34,7 @@ ecovalence <- function(.data, env, gen, rep, resp, verbose = TRUE) {
   factors  <-
     .data %>%
     select({{env}}, {{gen}}, {{rep}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <-
     .data %>%
     select({{resp}}, -names(factors)) %>%
