@@ -38,7 +38,7 @@ ge_means <- function(.data, env, gen, resp) {
   factors  <-
     .data %>%
     select({{env}}, {{gen}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <- .data %>% select({{resp}}, -names(factors))
   vars %<>% select_numeric_cols()
   factors %<>% set_names("ENV", "GEN")
