@@ -32,7 +32,7 @@
 #'
 #'}
 #' @references Eberhart, S.A., and W.A. Russell. 1966. Stability parameters for comparing Varieties.
-#' Crop Sci. 6:36-40. \href{https://www.crops.org/publications/cs/abstracts/6/1/CS0060010036}{doi:10.2135/cropsci1966.0011183X000600010011x}.
+#' Crop Sci. 6:36-40. \href{https://doi.org/10.2135/cropsci1966.0011183X000600010011x}{doi:10.2135/cropsci1966.0011183X000600010011x}.
 
 ge_reg = function(.data,
                   env,
@@ -43,7 +43,7 @@ ge_reg = function(.data,
   factors  <-
     .data %>%
     select({{env}}, {{gen}}, {{rep}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <-
     .data %>%
     select({{resp}}, -names(factors)) %>%
