@@ -98,7 +98,7 @@ gge <- function(.data,
   factors  <-
     .data %>%
     select({{env}}, {{gen}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <- .data %>% select({{resp}}, -names(factors))
   vars %<>% select_numeric_cols()
   factors %<>% set_names("ENV", "GEN")
