@@ -41,7 +41,7 @@ superiority <- function(.data, env, gen, resp, verbose = TRUE) {
   factors  <-
     .data %>%
     select({{env}}, {{gen}}) %>%
-    mutate_all(as.factor)
+    mutate(across(everything(), as.factor))
   vars <-
     .data %>%
     select({{resp}}, -names(factors)) %>%
