@@ -396,8 +396,15 @@ replace_string <- function(.data,
 }
 #' @name utils_num_str
 #' @export
-#' @importFrom dplyr mutate_if transmute
+#' @importFrom dplyr transmute
 round_cols <- function(.data, ...,  digits = 2){
+  is_mat <- is.matrix(.data)
+  if(is_mat ==  TRUE){
+    .data <-
+      .data %>%
+      as.data.frame() %>%
+      rownames_to_column()
+  }
   rn_test <- has_rownames(.data)
   if(rn_test == TRUE){
     rnames <- rownames(.data)
@@ -410,6 +417,12 @@ round_cols <- function(.data, ...,  digits = 2){
   if(rn_test == TRUE){
     rownames(.data) <- rnames
   }
+  if(is_mat ==  TRUE){
+    .data <-
+      .data %>%
+      column_to_rownames() %>%
+      as.matrix()
+  }
   return(.data)
 }
 #' @name utils_num_str
@@ -1026,6 +1039,30 @@ kurt <- function(.data, ..., na.rm = FALSE) {
 }
 #' @name utils_stats
 #' @export
+pseudo_sigma <- function(.data, ..., na.rm = FALSE) {
+  funct <- function(df){
+    IQR(df, na.rm = na.rm) / 1.35
+  }
+  if(has_na(.data) && na.rm == FALSE){
+    stop("NA values in data. Use 'na.rm = TRUE' to remove NAs from analysis.\nTo remove rows with NA use `remove_rows_na()'. \nTo remove columns with NA use `remove_cols_na()'.", call. = FALSE)
+  }
+  if(is.null(nrow(.data))){
+    funct(.data)
+  } else{
+    if(missing(...)){
+      .data %>%
+        summarise(across(where(is.numeric), funct)) %>%
+        ungroup()
+    } else{
+      .data %>%
+        select_cols(group_vars(.), ...) %>%
+        summarise(across(where(is.numeric), funct)) %>%
+        ungroup()
+    }
+  }
+}
+#' @name utils_stats
+#' @export
 range_data <- function(.data, ..., na.rm = FALSE){
   funct <- function(df){
     max(df, na.rm = na.rm) - min(df, na.rm = na.rm)
@@ -1308,6 +1345,13 @@ sem_by <- function(.data, ..., na.rm = FALSE){
   group_by(.data, ...) %>%
     summarise(across(where(is.numeric), sem, na.rm = na.rm), .groups = "drop")
 }
+#' @name utils_stats
+#' @export
+sum_by <- function(.data, ..., na.rm = FALSE){
+  group_by(.data, ...) %>%
+    summarise(across(where(is.numeric), sum, na.rm = na.rm), .groups = "drop")
+}
+
 #' @title Utilities for handling with matrices
 #'
 #' @description These functions help users to make upper, lower, or symmetric
@@ -1528,12 +1572,6 @@ stars_pval <- function(p_value){
 
 
 
-
-
-
-
-
-
 #' Check if a data set is balanced
 #'
 #' Check if a data set coming from multi-environment trials is balanced, i.e.,
@@ -1568,9 +1606,118 @@ is_balanced_trial <- function(.data, env, gen, resp){
   }
 }
 
-# For internal use only
+
+
+#' Utilities for data Copy-Pasta
+#' @name utils_data
+#' @description
+#' These functions allows interacting with the system clipboard. It is possible
+#' read from the clipboard or write a data frame or matrix to the clipboard.
+#' * \code{clip_read()} read data from the clipboard.
+#' * \code{clip_write()} write data to the clipboard.
+#'
+#' @param .data The data that should be copied to the clipboard. Only data frames and matrices are allowed
+#' @param header If the copied data has a header row for dataFrame, defaults to
+#'   \code{TRUE}.
+#' @param sep The separator which should be used in the copied output.
+#' @param row_names Decides if the output should keep row names or not, defaults
+#'   to \code{FALSE}.
+#' @param col_names Decides if the output should keep column names or not,
+#'   defaults to \code{TRUE}.
+#' @md
+#' @param ... Further arguments to be passed to \code{\link[utils]{read.table}()}.
+#' @export
+#' @importFrom utils read.table write.table
+#' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
+#' @return Nothing
+#'
+clip_read <- function(header = TRUE, sep = "\t", ...){
+  os <- get_os()
+  if(os == "windows"){
+    df <- read.table("clipboard", sep = sep, header = header, ...)
+  }
+  if(os == "osx"){
+    df <- read.table(pipe("pbpaste"), sep = sep, header = header, ...)
+  }
+  if(os == "linux"){
+    if (!file.exists(Sys.which("xclip")[1L])){
+      stop("Cannot find xclip. Try installing it with 'sudo apt-get install xclip'")
+    }
+    df <- read.table(pipe("xclip -selection clipboard -o", open = "r"), ...)
+  }
+  return(as_tibble(df))
+}
+#' @name utils_data
+#' @export
+clip_write <- function(.data,
+                       sep = "\t",
+                       row_names = FALSE,
+                       col_names = TRUE, ...){
+  os <- get_os()
+  if(os == "windows"){
+    if(!has_class(.data , c("data.frame", "matrix"))){
+      stop("Only data frames/tibbles/matrices allowed.")
+    }
+    write.table(.data,
+                "clipboard",
+                sep = sep,
+                row.names = row_names,
+                col.names = col_names,
+                ...)
+    message("Object '", match.call()[".data"], "' copied to the clipboard")
+  }
+  if(os == "osx"){
+    if(!has_class(.data , c("data.frame", "matrix"))){
+      stop("Only data frames/tibbles/matrices allowed.")
+    }
+    write.table(.data,
+                file = pipe("pbcopy"),
+                sep = sep,
+                row.names = row_names,
+                col.names = col_names,
+                ...)
+    message("Object '", match.call()[".data"], "' copied to the clipboard")
+  }
+  if(os == "linux"){
+    if(!has_class(.data , c("data.frame", "matrix"))){
+      stop("Only data frames/tibbles/matrices allowed.")
+    }
+    if (!file.exists(Sys.which("xclip")[1L])){
+      stop("Cannot find xclip. Try installing it with 'sudo apt-get install xclip'")
+    }
+    write.table(.data,
+                file = pipe("xclip -selection clipboard -i", open="w"),
+                sep = sep,
+                row.names = row_names,
+                col.names = col_names,
+                ...)
+  }
+}
+
+
+
+### For internal use only ##
+# Check labels
 check_labels <- function(.data){
   if(any(sapply(.data, grepl, pattern = ":"))){
     stop("Using ':' in genotype or environment labels is not allowed. Use '_' instead.\ne.g., replace_string(data, ENV, pattern = ':', replacement = '_', new_var = ENV)", call. = FALSE)
   }
 }
+# Get the OS
+get_os <- function(){
+  sysinf <- Sys.info()
+  if (!is.null(sysinf)){
+    os <- sysinf['sysname']
+    if (os == 'Darwin')
+      os <- "osx"
+  } else {
+    os <- .Platform$OS.type
+    if (grepl("^darwin", R.version$os)){
+      os <- "osx"
+    }
+    if (grepl("linux-gnu", R.version$os)){
+      os <- "linux"
+    }
+  }
+  return(all_lower_case(os))
+}
